cmd

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 6, 2026 License: MIT Imports: 57 Imported by: 0

Documentation

Overview

Package cmd contains all the command-line interface definitions and implementations for the unirtm application. It uses cobra library to handle command-line parsing, flag management, and command execution.

Package cmd contains all the command-line interface definitions and implementations for the unirtm application. This file implements shell completion generation commands.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute executes the root command.

func RegisterInstallCommand

func RegisterInstallCommand()

RegisterInstallCommand registers the install command to the root command. This function should be called after rootCmd is initialized.

func RegisterUninstallCommand

func RegisterUninstallCommand()

RegisterUninstallCommand registers the uninstall command to the root command. This function should be called after rootCmd is initialized.

Types

type DepEntry

type DepEntry struct {
	Ecosystem    string
	Directory    string
	TargetBranch string
	PrLimit      int
	Interval     string
	Day          string
	Cooldown     int
	Prefix       string
	Labels       []string
}

type DetectedVersion

type DetectedVersion struct {
	Tool         string
	Version      string
	Source       string // nvm, pyenv, rbenv, asdf
	ExternalPath string
}

Jump to