Documentation
¶
Overview ¶
Package cmd contains all the command-line interface definitions and implementations for the unirtm application. It uses cobra library to handle command-line parsing, flag management, and command execution.
Package cmd contains all the command-line interface definitions and implementations for the unirtm application. This file implements shell completion generation commands.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterInstallCommand ¶
func RegisterInstallCommand()
RegisterInstallCommand registers the install command to the root command. This function should be called after rootCmd is initialized.
func RegisterUninstallCommand ¶
func RegisterUninstallCommand()
RegisterUninstallCommand registers the uninstall command to the root command. This function should be called after rootCmd is initialized.
Types ¶
Source Files
¶
- 0.cmd.go
- 1.main.go
- 10.deactivate.go
- 11.search.go
- 12.update.go
- 13.cache.go
- 14.config.go
- 15.doctor.go
- 16.migrate.go
- 17.use.go
- 18.shell.go
- 19.where.go
- 20.which.go
- 21.reshim.go
- 22.prune.go
- 23.exec.go
- 24.plugin.go
- 25.run.go
- 26.trust.go
- 27.untrust.go
- 28.watch.go
- 29.alias.go
- 3.env.go
- 30.settings.go
- 31.lock.go
- 32.outdated.go
- 33.latest.go
- 34.set.go
- 35.tool.go
- 36.bin-paths.go
- 37.backends.go
- 38.registry.go
- 39.tasks.go
- 4.version.go
- 40.fmt.go
- 41.link.go
- 42.unuse.go
- 43.self-update.go
- 44.implode.go
- 45.generate.go
- 45.generate_dependabot.go
- 46.enable.go
- 47.disable.go
- 48.install-into.go
- 49.edit.go
- 5.completion.go
- 50.token.go
- 51.mcp.go
- 52.ls-remote.go
- 53.prepare.go
- 54.index.go
- 54.sync.go
- 55.hook-env.go
- 55.test-tool.go
- 56.tool-stub.go
- 57.current.go
- 6.install.go
- 60.license.go
- 61.df.go
- 62.hook.go
- 7.uninstall.go
- 8.list.go
- 9.activate.go